@@ -32,6 +32,7 @@ import numpy as np
 from equilibrator_cache import FARADAY, Q_, Compound, R, Reaction, ureg
 from equilibrator_cache.exceptions import MissingDissociationConstantsException
 from equilibrator_cache.thermodynamic_constants import default_pMg
+from scipy.linalg import pinvh
 
 from . import CCModelParameters, Preprocessor
 from .linalg import LINALG
@@ -105,18 +106,21 @@ class GibbsEnergyPredictor(object):
             another matrix with the square root of the covariance corresponding
             to the 'unknown' compounds (i.e. where the uncertainty is infinite)
         uncertainty_representation : str
-            which representation to use for the uncertainties. 'cov' would
-            return a full covariance matrix. 'sqrt' would return a sqaure root
-            of the covariance, based on the uncertainty vectors.
-            'fullrank' would return a full-rank square root of the covariance
-            which is a compressed form of the 'sqrt' result.
-            (Default value: 'cov')
+            which representation to use for the uncertainties.
+            `cov` would return a full covariance matrix.
+            `precision` would return the precision matrix
+            (i.e. the inverse of the covariance matrix).
+            `sqrt` would return a sqaure root of the covariance,
+            based on the uncertainty vectors.
+            `fullrank` would return a full-rank square root of the covariance
+            which is a compressed form of the `sqrt` result.
+            (Default value: `cov`)
 
         Returns
         -------
         dg_uncertainty : Quantity
-            the uncertainty co-variance matrix
-            (in either 'cov', 'sqrt' or 'fullrank' format)
+            the uncertainty matrix (in either `cov`, `precision`, `sqrt or
+            `fullrank` format)
 
         """
         sigma = np.hstack(
@@ -129,6 +133,8 @@ class GibbsEnergyPredictor(object):
 
         if uncertainty_representation == "cov":
             dg_uncertainty = Q_(sigma @ sigma.T, "(kJ/mol)**2")
+        elif uncertainty_representation == "precision":
+            dg_uncertainty = Q_(pinvh(sigma @ sigma.T), "(mol/kJ)**2")
         elif uncertainty_representation == "sqrt":
             dg_uncertainty = Q_(sigma, "kJ/mol")
         elif uncertainty_representation == "fullrank":
@@ -212,12 +218,15 @@ class GibbsEnergyPredictor(object):
         reactions : List[Reaction]
             a list of Reaction objects
         uncertainty_representation : str
-            which representation to use for the uncertainties. 'cov' would
-            return a full covariance matrix. 'sqrt' would return a sqaure root
-            of the covariance, based on the uncertainty vectors.
-            'fullrank' would return a full-rank square root of the covariance
-            which is a compressed form of the 'sqrt' result.
-            (Default value: 'cov')
+            which representation to use for the uncertainties.
+            `cov` would return a full covariance matrix.
+            `precision` would return the precision matrix
+            (i.e. the inverse of the covariance matrix).
+            `sqrt` would return a sqaure root of the covariance,
+            based on the uncertainty vectors.
+            `fullrank` would return a full-rank square root of the covariance
+            which is a compressed form of the `sqrt` result.
+            (Default value: `cov`)
 
         Returns
         -------
@@ -225,11 +234,9 @@ class GibbsEnergyPredictor(object):
             the array of Component Contribution estimates for the reactions'
             untransformed :math:`\Delta G` in kJ/mol,
             (i.e. using the major MS at pH 7 for each of the reactants).
-        cov_dg : Quantity
-            the covariance matrix of the standard errors of the estimates.
-            one can use the eigenvectors of the matrix to define a confidence
-            high-dimensional space, or use U as the covariance of a Gaussian
-            used for sampling (where cov_dg is the mean of that Gaussian).
+        dg_uncertainty : Quantity
+            the uncertainty matrix (in either `cov`, `precision`, `sqrt or
+            `fullrank` format)
 
         """
         (
@@ -409,7 +416,7 @@ class GibbsEnergyPredictor(object):
         p_h_2: Q_,
         ionic_strength_1: Q_,
         ionic_strength_2: Q_,
-        delta_chi: Q_,
+        e_potential_difference: Q_,
         temperature: Q_,
         p_mg_1: Q_ = default_pMg,
         p_mg_2: Q_ = default_pMg,
@@ -439,7 +446,7 @@ class GibbsEnergyPredictor(object):
             the ionic strength in compartment 1
         ionic_strength_2 : Quantity
             the ionic strength in compartment 2
-        delta_chi : Quantity
+        e_potential_difference : Quantity
             electrostatic potential across the membrane
         temperature : Quantity
             temperature in Kalvin
@@ -492,7 +499,7 @@ class GibbsEnergyPredictor(object):
             * (p_h_2 - p_h_1)
         )
 
-        dg_electrostatic = FARADAY * transported_charge * delta_chi
+        dg_electrostatic = FARADAY * transported_charge * e_potential_difference
 
         standard_dg += transform_dg - dg_protons - dg_electrostatic
         return standard_dg.to("kJ/mol")
